¡Hola! esta libreria esta disenada para resolver sistemas de ecuaciones lineales y no lineales.

## Metodos implementados

### Sistemas lineales
- Eliminacion Gaussiana
- Gauss-Jordan
- Regla de Cramer
- Descomposición LU
- Jacobi
- Gauss-Seidel

### Sistemas no lineales
- Metodo de Bisección

## Instalacion

```bash
pip install 0265831UNO